@@ -107,50 +107,38 @@ get_root_key(const char *root)
     return NULL;
   return root_key;
 }
+#if defined(_WIN64)
+#define CROSS_ACCESS KEY_WOW64_32KEY
+#else
+#define CROSS_ACCESS KEY_WOW64_64KEY
+#endif
 
-static std::string
-readRegStr (const char *root, const char *dir, const char *name)
+std::string
+_readRegStr (HKEY root_key, const char *dir,
+             const char *name, bool alternate)
 {
 #ifndef _WIN32
-    (void)root; (void)dir; (void)name;
+    (void) root_key; (void)alternate; (void)dir; (void)name;
     return std::string();
 #else
-
-    HKEY root_key, key_handle;
+    HKEY key_handle;
     DWORD n1, nbytes, type;
     std::string ret;
 
-    if (!(root_key = get_root_key(root))) {
-        return ret;
+    DWORD flags = KEY_READ;
+
+    if (alternate) {
+        flags |= CROSS_ACCESS;
     }
 
-    if (RegOpenKeyExA(root_key, dir, 0, KEY_READ, &key_handle)) {
-        if (root) {
-            /* no need for a RegClose, so return direct */
-            return ret;
-        }
-        /* Fallback to HKLM */
-
-        if (RegOpenKeyExA(HKEY_LOCAL_MACHINE, dir, 0, KEY_READ, &key_handle)) {
-            return ret;
-        }
+    if (RegOpenKeyExA(root_key, dir, 0, flags, &key_handle)) {
+        return ret;
     }
 
     nbytes = 1;
     if (RegQueryValueExA(key_handle, name, 0, nullptr, nullptr, &nbytes)) {
-        if (root) {
-            RegCloseKey (key_handle);
-            return ret;
-        }
-        /* Try to fallback to HKLM also vor a missing value.  */
         RegCloseKey (key_handle);
-        if (RegOpenKeyExA (HKEY_LOCAL_MACHINE, dir, 0, KEY_READ, &key_handle)) {
-            return ret;
-        }
-        if (RegQueryValueExA(key_handle, name, 0, nullptr, nullptr, &nbytes)) {
-            RegCloseKey(key_handle);
-            return ret;
-        }
+        return ret;
     }
     n1 = nbytes+1;
     char result[n1];
@@ -182,6 +170,33 @@ readRegStr (const char *root, const char *dir, const char *name)
         }
     }
     return ret;
+
+#endif
+}
+
+std::string
+readRegStr (const char *root, const char *dir, const char *name)
+{
+#ifndef _WIN32
+    (void)root; (void)dir; (void)name;
+    return std::string();
+#else
+    HKEY root_key;
+    std::string ret;
+    if (!(root_key = get_root_key(root))) {
+        return ret;
+    }
+    ret = _readRegStr (root_key, dir, name, false);
+
+    if (ret.empty()) {
+        // Try local machine as fallback.
+        ret = _readRegStr (HKEY_LOCAL_MACHINE, dir, name, false);
+        if (ret.empty()) {
+            // Try alternative registry view as fallback
+            ret = _readRegStr (HKEY_LOCAL_MACHINE, dir, name, true);
+        }
+    }
+    return ret;
 #endif
 }
 
@@ -770,78 +785,6 @@ gpgol_bug (HWND parent, int code)
   return;
 }
 
-static char*
-expand_path (const char *path)
-{
-  DWORD len;
-  char *p;
-
-  len = ExpandEnvironmentStrings (path, NULL, 0);
-  if (!len)
-    {
-      return NULL;
-    }
-  len += 1;
-  p = (char *) xcalloc (1, len+1);
-  if (!p)
-    {
-      return NULL;
-    }
-  len = ExpandEnvironmentStrings (path, p, len);
-  if (!len)
-    {
-      xfree (p);
-      return NULL;
-    }
-  return p;
-}
-
-static int
-load_config_value (HKEY hk, const char *path, const char *key, char **val)
-{
-  HKEY h;
-  DWORD size=0, type;
-  int ec;
-
-  *val = NULL;
-  if (hk == NULL)
-    {
-      hk = HKEY_CURRENT_USER;
-    }
-  ec = RegOpenKeyEx (hk, path, 0, KEY_READ, &h);
-  if (ec != ERROR_SUCCESS)
-    {
-      return -1;
-    }
-
-  ec = RegQueryValueEx(h, key, NULL, &type, NULL, &size);
-  if (ec != ERROR_SUCCESS)
-    {
-      RegCloseKey (h);
-      return -1;
-    }
-  if (type == REG_EXPAND_SZ)
-    {
-      char tmp[256];
-      RegQueryValueEx (h, key, NULL, NULL, (BYTE*)tmp, &size);
-      *val = expand_path (tmp);
-    }
-  else
-    {
-      *val = (char *) xcalloc(1, size+1);
-      ec = RegQueryValueEx (h, key, NULL, &type, (BYTE*)*val, &size);
-      if (ec != ERROR_SUCCESS)
-        {
-          xfree (*val);
-          *val = NULL;
-          RegCloseKey (h);
-          return -1;
-        }
-    }
-  RegCloseKey (h);
-  return 0;
-}
-
 static int
 store_config_value (HKEY hk, const char *path, const char *key, const char *val)
 {
@@ -885,14 +828,16 @@ store_extension_value (const char *key, const char *val)
 int
 load_extension_value (const char *key, char **val)
 {
-  int ret = load_config_value (HKEY_CURRENT_USER, GPGOL_REGPATH, key, val);
-  if (val)
+  if (!val)
     {
-      log_debug ("%s:%s: LoadReg '%s' val '%s'",
-                 SRCNAME, __func__, key ? key : "null",
-                 *val ? *val : "null");
+      STRANGEPOINT;
+      return -1;
     }
-  return ret;
+  *val = read_w32_registry_string (nullptr, GPGOL_REGPATH, key);
+  log_debug ("%s:%s: LoadReg '%s' val '%s'",
+             SRCNAME, __func__, key ? key : "null",
+             *val ? *val : "null");
+  return 0;
 }
 
 int
